@@ -18,10 +18,14 @@ github_userlib <- function(gituser, gitrepo){
   file.path(github_rootpath(), paste(github_prefix, gituser, gitrepo, sep="_"))
 }
 
-github_package_info <- function(repo){
+github_package_info <- function(repo, token = NULL){
   tryCatch({
   url <- sprintf("https://raw.githubusercontent.com/%s/master/DESCRIPTION", repo)
-  con <- curl::curl(url)
+  handle <- curl::new_handle()
+  if(length(token)){
+    curl::handle_setheaders(handle, Authorization = paste("token", token))
+  }
+  con <- curl::curl(url, handle = handle)
   on.exit(close(con))
   out <- as.list(as.data.frame(read.dcf(con), stringsAsFactors = FALSE))
   }, error = function(e){
@@ -30,10 +34,11 @@ github_package_info <- function(repo){
   stats::setNames(out, tolower(names(out)))
 }
 
-github_install <- function(repo, username, ref, args = NULL, upgrade_dependencies = FALSE, ...){
+github_install <- function(repo, username, ref, args = NULL, upgrade_dependencies = FALSE, auth_token = github_token(), ...){
   #get args
   all_args <- list(...)
   all_args$upgrade_dependencies <- upgrade_dependencies
+  all_args$auth_token <- auth_token
   all_args$repo <- url_path(username, repo)
   all_args$ref <- ref
 
@@ -46,15 +51,9 @@ github_install <- function(repo, username, ref, args = NULL, upgrade_dependencie
 
   # Download metadata before actually installing. Errors if no DESCRIPTION exists.
   # TODO: get this info from 'output' above
-  app_info <- github_package_info(all_args$repo)
+  app_info <- github_package_info(all_args$repo, auth_token)
   package <- app_info$package
 
-  #Override auth_token if set in key
-  mysecret <- gitsecret()
-  if(length(mysecret) && length(mysecret$auth_token) && nchar(mysecret$auth_token)){
-    all_args$auth_token = mysecret$auth_token
-  }
-
   # Create the Rscript call
   arg_list <- paste(deparse(all_args), collapse="\n")
   output <- run_rscript(sprintf("do.call(opencpu:::install_apps_one, %s)", arg_list))
